@@ -58,8 +58,14 @@ void translate()
 	gtk_text_buffer_get_end_iter(buffer_source, &end);
 	text = gtk_text_buffer_get_text(buffer_source, &start, &end, FALSE);
 	
+	if (g_strcmp0(text, "") == 0)
+	{
+		show_alert("Please enter valid text!");
+		return;
+	}
+	
 	SoupMessage* msg;
-	gchar* url = g_strdup_printf("http://www.google.com/translate_a/t?client=t&ie=UTF-8&sl=%s&tl=%s&ie=utf-8&oe=utf-8",
+	gchar* url = g_strdup_printf("http://www.google.com/translate_a/t?client=gtranslate&ie=UTF-8&sl=%s&tl=%s&ie=utf-8&oe=utf-8",
 										languages[index_src_lang].str_short, languages[index_tar_lang].str_short);
 	msg = soup_message_new("POST", url);
 	g_free(url);
@@ -266,21 +272,21 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 	
 	if (g_strcmp0(language_string, languages[n].str_long) != 0)
 	{
-		g_debug("search on!\n");
+		//g_debug("search on!\n");
 		
 		for (n = 0; n < 52; n++)
 		{
 			if (g_strcmp0(language_string, languages[n].str_long) == 0)
 			{
-				g_debug("%s = %s\n", language_string, languages[n].str_long);
+				//g_debug("%s = %s\n", language_string, languages[n].str_long);
 				break;
 			}
 		}
 	}
-	else
+	/*else
 	{
 		g_debug("search off!\n");
-	}
+	}*/
 	
 	if ((gint)data == 1)
 	{
@@ -289,10 +295,18 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 		index_src_lang = n;
 		hildon_button_set_image(HILDON_BUTTON(button_src_lang), gtk_image_new_from_pixbuf(flags[n]));
 		gtk_widget_set_sensitive(button_say1, languages[n].espeak);
+		
+		if (n == 0)
+		{
+			gtk_widget_set_sensitive(button_swap, FALSE);
+		}
+		else
+		{
+			gtk_widget_set_sensitive(button_swap, TRUE);
+		}
 	}
 	else
 	{
-		//n++;
 		hildon_button_set_value(HILDON_BUTTON(button_tar_lang), languages[n].str_long);
 		settings_int_set("default", "tar_lang", n);
 		index_tar_lang = n;
@@ -300,25 +314,16 @@ void row_activated(GtkWidget* tree_view, GtkTreePath* path, GtkTreeViewColumn* c
 		gtk_widget_set_sensitive(button_say2, languages[n].espeak);
 	}
 	
-	if (index == 0)
-	{
-		gtk_widget_set_sensitive(button_swap, FALSE);
-		//gtk_widget_set_sensitive(button_say1, FALSE);
-	}
-	else
-	{
-		gtk_widget_set_sensitive(button_swap, TRUE);
-		//gtk_widget_set_sensitive(button_say1, TRUE);
-	}
-	
- 	//g_print("select item: %s = %s\n", languages[index_src_lang].str_short, languages[index_src_lang].str_long);
  	gtk_widget_destroy(dialog);
 }
 
 void show_about(GtkWidget* widget, gpointer data)
 {
 	GtkWidget* about_dialog;
-	GtkWidget* table = gtk_table_new(3, 2, TRUE);
+	about_dialog = gtk_dialog_new();
+	gtk_window_set_title(GTK_WINDOW(about_dialog), "About "PACKAGE_STRING);
+	gtk_window_set_transient_for(GTK_WINDOW(about_dialog), GTK_WINDOW(window));
+	/*GtkWidget* table = gtk_table_new(3, 2, TRUE);
 	
 	about_dialog = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(about_dialog), "About "PACKAGE_STRING);
@@ -335,11 +340,116 @@ void show_about(GtkWidget* widget, gpointer data)
 	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("Powered by:"), 0, 2, 1, 2);
 	gtk_table_attach_defaults(GTK_TABLE(table), gtk_image_new_from_file(DATAPREFIX"/google.png"), 0, 2, 2, 3);
 	
-	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox), table);
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox), table);*/
+	
+	GtkWidget* text = hildon_text_view_new();
+	gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
+	gtk_text_view_set_cursor_visible(GTK_TEXT_VIEW(text), FALSE);
+	
+	GdkPixbuf* google_translate = gdk_pixbuf_new_from_file(DATAPREFIX"/google.png", NULL);
+	
+	GtkTextBuffer* buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+	
+	GtkTextIter iter;
+	gtk_text_buffer_get_end_iter(buffer, &iter);
+	
+	gtk_text_buffer_insert(buffer, &iter, "Programming and flag graphics:\n  TomppaS\n\nIcons:\n  Joppu\n\nPowered by:\n  eSpeak: Speech Synthesizer\n  ", -1);
+	
+	gtk_text_buffer_insert_pixbuf(buffer, &iter, google_translate);
+	
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(about_dialog)->vbox), text);
 	
 	gtk_widget_show_all(about_dialog);
 }
 
+GtkWidget* settings_dialog;
+
+/*GtkWidget* radio_male;
+GtkWidget* radio_female;*/
+
+GtkWidget* slider_pitch;
+GtkWidget* slider_speed;
+GtkWidget* slider_wordgap;
+
+void settings_response(GtkDialog* dialog, gint response_id, gpointer user_data)
+{
+	if (response_id == GTK_RESPONSE_OK)
+	{
+		settings_int_set("voice", "pitch", (gint)gtk_range_get_value(GTK_RANGE(slider_pitch)));
+		settings_int_set("voice", "speed", (gint)gtk_range_get_value(GTK_RANGE(slider_speed)));
+		settings_int_set("voice", "wordgap", (gint)gtk_range_get_value(GTK_RANGE(slider_wordgap)));
+		
+		/*if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_male)))
+		{
+			settings_int_set("voice", "gender", 1);
+		}
+		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_female)))
+		{
+			settings_int_set("voice", "gender", 2);
+		}*/
+		
+		gtk_widget_destroy(GTK_DIALOG(settings_dialog));
+	}
+}
+
+void show_settings(GtkWidget* widget, gpointer data)
+{
+	settings_dialog = gtk_dialog_new_with_buttons("Settings", window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL);
+	//gtk_window_set_title(GTK_WINDOW(settings_dialog), "Settings");
+	gtk_window_set_transient_for(GTK_WINDOW(settings_dialog), GTK_WINDOW(window));
+	
+	//GtkWidget* caption_speech = gtk_label_new("Speech Synthesizer");
+	
+	/*radio_male = hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT, NULL);
+	gtk_button_set_label(GTK_BUTTON(radio_male), "Male");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(radio_male), FALSE);
+	
+	radio_female = hildon_gtk_radio_button_new(HILDON_SIZE_FINGER_HEIGHT, gtk_radio_button_get_group(GTK_RADIO_BUTTON(radio_male)));
+	gtk_button_set_label(GTK_BUTTON(radio_female), "Female");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(radio_female), FALSE);*/
+	
+	/*if (settings_int_get("voice", "gender", 1) == 1)
+	{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_male), TRUE);
+	}
+	else
+	{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_female), TRUE);
+	}*/
+	
+	/*GtkWidget* gender_hbox = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(gender_hbox), radio_male,   TRUE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(gender_hbox), radio_female, TRUE, TRUE, 0);*/
+	
+	slider_pitch = gtk_hscale_new_with_range(-50.0, 50.0, 1.0);
+	gtk_scale_set_value_pos(GTK_SCALE(slider_pitch), GTK_POS_RIGHT);
+	gtk_range_set_value(GTK_RANGE(slider_pitch), (gdouble)settings_int_get("voice", "pitch", 0));
+	
+	slider_speed = gtk_hscale_new_with_range(80.0, 390.0, 2.0);
+	gtk_scale_set_value_pos(GTK_SCALE(slider_speed), GTK_POS_RIGHT);
+	gtk_range_set_value(GTK_RANGE(slider_speed), (gdouble)settings_int_get("voice", "speed", 181));
+	
+	slider_wordgap = gtk_hscale_new_with_range(0.0, 20.0, 1.0);
+	gtk_scale_set_value_pos(GTK_SCALE(slider_wordgap), GTK_POS_RIGHT);
+	gtk_range_set_value(GTK_RANGE(slider_wordgap), (gdouble)settings_int_get("voice", "wordgap", 5));
+	
+	GtkWidget* vbox = gtk_vbox_new(TRUE, 0);
+	//gtk_box_pack_start(GTK_BOX(vbox), caption_speech, FALSE, TRUE, 0);
+	//gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Gender\t\t", gender_hbox,    NULL, 0),  FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Pitch\t\t",  slider_pitch,   NULL, 0),  FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Speed\t\t",  slider_speed,   NULL, 0),  FALSE, TRUE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hildon_caption_new(NULL, "Word gap\t", slider_wordgap, NULL, 0),  FALSE, TRUE, 0);
+	
+	GtkWidget* frame_speech = gtk_frame_new("Speech Synthesizer");
+	gtk_container_add(GTK_CONTAINER(frame_speech), vbox);
+	
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(settings_dialog)->vbox), frame_speech);
+	
+	g_signal_connect_swapped(settings_dialog, "response", G_CALLBACK(settings_response), NULL);
+	
+	gtk_widget_show_all(settings_dialog);
+}
+
 static gboolean filter_func(GtkTreeModel* model, GtkTreeIter* iter, gchar* text, gpointer data)
 {
 	gboolean retvalue;
@@ -485,8 +595,20 @@ void say_text(GtkWidget* widget, gint data)
 		lang = g_strdup(languages[index_tar_lang].str_short);
 	}
 	
-	espeak_Initialize(AUDIO_OUTPUT_PLAYBACK, 0, NULL,0);
+	espeak_Initialize(AUDIO_OUTPUT_PLAYBACK, 0, NULL, 0);
+	
 	espeak_SetVoiceByName(lang);
+	
+	/*espeak_VOICE *voice_spec = espeak_GetCurrentVoice();
+	voice_spec->gender = (char)settings_int_get("voice", "gender", 1) + 48;
+	espeak_SetVoiceByProperties(voice_spec);
+	
+	g_debug("gender = %c\n", voice_spec->gender);*/
+	
+	espeak_SetParameter(espeakRATE,    settings_int_get("voice", "speed", 181), 0);
+	espeak_SetParameter(espeakPITCH,   settings_int_get("voice", "pitch", 0) + 50, 0);
+	espeak_SetParameter(espeakWORDGAP, settings_int_get("voice", "wordgap", 5), 0);
+	
 	espeak_Synth(text,strlen(text)+1,0,POS_CHARACTER,0,0,NULL,NULL);
 	espeak_Synchronize();
 	espeak_Terminate();
