@@ -132,7 +132,14 @@ void create_window()
 	/* Create a menu */
 	HildonAppMenu* menu = HILDON_APP_MENU(hildon_app_menu_new());
 	
-	GtkWidget* button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+	GtkWidget* button;	
+	
+	button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
+	gtk_button_set_label(GTK_BUTTON(button), "Settings");
+	g_signal_connect_after(G_OBJECT(button), "clicked", G_CALLBACK(show_settings), NULL);
+	hildon_app_menu_append(menu, GTK_BUTTON(button));
+	
+	button = hildon_gtk_button_new(HILDON_SIZE_AUTO);
 	gtk_button_set_label(GTK_BUTTON(button), "About");
 	g_signal_connect_after(G_OBJECT(button), "clicked", G_CALLBACK(show_about), NULL);
 	hildon_app_menu_append(menu, GTK_BUTTON(button));
